@@ -11,29 +11,55 @@
 #include "typetraits.h"
 #include <string>
 
+
 using namespace std;
 
 /**Base class for all vector types, it holds the size and handles some 
-   common operations for all vector types
+   common operations for all vector types.
    @author Jean-Marc Valin
 */
 class BaseVector  : public Object {
   protected:
-   size_t obj_size;
-   size_t obj_capacity;
+
   public:
-   BaseVector(size_t _obj_size, size_t _obj_capacity)
-      : obj_size(_obj_size)
-      , obj_capacity(_obj_capacity)
-      {}
+  
+   ///constructor
+   BaseVector(){}
 
-   size_t size() const {return obj_size;}
-
-   bool empty() const {return size()==0;}
-
-   size_t capacity() {return obj_capacity;}
+   ///return vector size 
+   virtual size_t vsize() const = 0;
    
+   ///return true if vector empty
+   virtual bool vempty() const = 0;
+
+   /** 
+   	Returns a new vector (in an ObjectRef) with a range of indexes of the same type.
+	\param startInd start index
+	\param endInd end indix
+	\return new vector in an ObjectRef
+   */
    virtual ObjectRef range(size_t startInd, size_t endInd)=0;
+      
+   /**
+   	Returns an element (in an ObjectRef) of the vector
+	\param pos the position of the element
+	\return ObjectRef the newly created Object
+   */
+   virtual ObjectRef getIndex(int pos) = 0;
+   
+   /**
+   	Set an element value at the desired position
+	\param pos The position in the vector
+   	\param val The value to put at the desired position
+   */
+   virtual void setIndex(int pos, ObjectRef val) = 0;
+
+
+   /**
+      Clone the vector and return an identical copy (deep copy)
+   */
+   virtual ObjectRef clone() = 0;
+   
 };
 
 /**The (template) Overflow Vector type, it adds functionnality to the 
@@ -41,133 +67,92 @@ class BaseVector  : public Object {
    @author Jean-Marc Valin
 */
 template<class T>
-class Vector : public BaseVector {
-public:
-   typedef T& reference;
-   typedef const T& const_reference;
-   typedef T* iterator;
-   typedef const T* const_iterator;
-protected:
-   T *data;
+class Vector : public BaseVector , public vector<T> {
 public:
+
+   ///You can always get the type of the Vector elements by using typename Vector<T>::basicType.
+   typedef T basicType;
+
+   ///Default constructor, size of the vector is 0.
    Vector()
-      : BaseVector(0,0)
-      , data(NULL)
+      : BaseVector()
+      , vector<T> ()
    {}
 
+   ///Copy constructor
    Vector(const Vector<T> &v)
-      : BaseVector(v.obj_size,v.obj_size)
+      : BaseVector()
+      , vector<T> (v)
    {
-      if (obj_size)
-	 data=(T*)new char [obj_size*sizeof(T)];
-#if 1
-      for (size_t i=0;i<obj_size;i++)
-	 constr(data+i,v.data[i]);
-#else
-      memcpy(data, v.data, obj_size*sizeof(T));
-#endif
    }
 
-
+   /**
+      Constructor with a size and an initialization value.
+      \param n the size of the vector
+      \param x the initialization value
+   */
    explicit Vector(size_t n, const T &x = T())
-      : BaseVector(0,0)
-      , data(NULL)
-   {resize(n,x);}
+      : BaseVector()
+      , vector<T> (n, x)
+   {}
 
+   ///Destructor
    ~Vector()
    {
-      if (data)
-      {
-	 for (iterator i=begin();i!=end();i++)
-	    destr(i);
-	 delete[] (char *)(data);
-	 data = NULL;
-      }      
    }
-
-   Vector<T> &operator=(const Vector<T> &v)
-   {
-      if (&v != this)
-      {
-	 if (data)
-	 {
-	    for (iterator i=begin();i!=end();i++)
-	       destr(i);
-	    delete[] (char *)(data);
-	    data = NULL;
-	 }
-	 
-	 obj_size=v.obj_size;
-	 obj_capacity=v.obj_size;
-	 if (obj_size)
-	    data=(T*)new char [obj_size*sizeof(T)];
-#if 1
-	 for (size_t i=0;i<obj_size;i++)
-	    constr(data+i,v.data[i]);
-#else
-	 memcpy(data, v.data, obj_size*sizeof(T));
-#endif
-      }
-      return *this;
-   }
-
-   inline void resize(size_t new_size, const T &x = T());
-
-   iterator begin() {return data;}
-
-   const_iterator begin() const {return data;}
-
-   reference front() {return *data;}
-
-   const_reference front() const {return *data;}
-
-   reference back() {return data[obj_size-1];}
-
-   const_reference back() const {return data[obj_size-1];}
-
-   iterator end() {return data+obj_size;}
-
-   const_iterator end() const {return data+obj_size;}
-
-   T &operator[] (size_t i) 
-   {
-#ifdef RT_DEBUG
-      if (i>size() || i<0)
-         throw GeneralException ("Vector::operator[] index out of bounds", __FILE__, __LINE__);
-#endif
-      return data[i];
-   }
-   const T &operator[] (size_t i) const 
-   {
-#ifdef RT_DEBUG
-      if (i>size() || i<0)
-         throw GeneralException ("Vector::operator[] index out of bounds", __FILE__, __LINE__);
-#endif
-      return data[i];
-   }
-
-   void push_back(const T &x) {insert(end(),x);}
-
-   void push_front(const T &x) {insert(begin(),x);}
+ 
+   virtual size_t vsize() const {return this->size();}
    
-   inline void insert(iterator after, const T &x);
-
-   inline void erase(iterator item);
-
+   virtual bool vempty() const {return this->empty();}
+   
+   /**
+      Formatted output (only values) for Vectors <br>
+      <b>Format : </b> <i> element0 element1 ... element(size-1)</i>
+   */
    void prettyPrint(ostream &out=cout) const;
 
+   /**
+      Formatted output in the FlowDesigner format<br>
+      <b>Format : </b> \<Vector\<T\> <i> element0 element1 ... element(size - 1)</i> \>
+      \param out the output stream
+   */
    void printOn(ostream &out) const;
    
+   /**
+      Formatted input in the FlowDesigner format<br>
+      <b>Format : </b> \<Vector\<T\> <i> element0 element1 ... element(size - 1)</i> \>
+      \param in the input stream
+   */
    void readFrom(istream &in=cin);
 
+   /**
+      Binary output in the FlowDesigner format<br>
+      <b>Format : </b> {Vector\<T\> |<i>element0;element1;...; element(size - 1)</i> }
+      \param out the output stream
+   */
    virtual void serialize(ostream &out) const;
 
+   /**
+      Binary input in the FlowDesigner format<br>
+      <b>Format : </b> {Vector\<T\> |<i>element0;element1;...; element(size - 1)</i> }
+      \param in the input stream
+   */
    virtual void unserialize(istream &in);
 
+   ///destroy() will be called by the vector pool to permanently delete a Vector<T> object
    virtual void destroy();
 
+   /**
+      alloc() is called to allocate a vector on the vector pool. The vector, if not used will be
+      placed in the vector pool to be reused later.
+      \param size size of the vector.
+   */
    static Vector<T> *alloc(size_t size);
 
+   /**
+      Returns the class name : Vector<T>
+      \return string the class name
+   */
    static string GetClassName()
    {
       string name = ObjectGetClassName<Vector<T> >();
@@ -178,12 +163,19 @@ public:
 	 return name;
    }
 
+   /**
+      Returns the class name : Vector<T>
+      \return string the class name
+   */
    string getClassName() {return GetClassName();}
+
    
-   T *ptr() {return data;}
-   
-   const T *ptr() const {return data;}
-   
+   /**
+      Returns a new vector containing data from start to end indexes.
+      \param startInd start index
+      \param endInd end index
+      \return ObjectRef the newly allocated vector 
+   */
    ObjectRef range(size_t startInd, size_t endInd)
    {
       Vector<T> *v = Vector<T>::alloc(endInd-startInd+1);
@@ -195,123 +187,55 @@ public:
       }
       return ObjectRef(v);
    }
+   
+   /**	
+   	Returns an element at a desired position in the vector
+   	\param pos the position in the vector
+	\return ObjectRef Element at the desired position
+   */
+   virtual ObjectRef getIndex(int pos);
 
-  protected:
-   void constr(T* ptr, const T& val) { new(ptr) T(val);}
-   void destr(T* ptr) { ptr->~T(); }
+   /**
+   	Set an element value at the desired position
+	\param pos The position in the vector
+   	\param val The value to put at the desired position
+   */
+   virtual void setIndex(int pos, ObjectRef val);
 
-  private:
-   size_t realloc_size(size_t new_size) {if (!obj_size) return new_size; return 1+size_t(new_size*1.5);}
+
+   /**
+      Clone the vector and return an identical copy (deep copy) 
+   */
+   virtual ObjectRef clone();
 };
 
 
-template<class T>
-void Vector<T>::resize(size_t new_size, const T &x)
-{
-   if (new_size > obj_size)
-   {
-      if (new_size > obj_capacity)
-      {
-	 size_t new_capacity = realloc_size(new_size);
-
-	 T* tmp = (T*)new char [new_capacity*sizeof(T)];
-#if 1
-	 for (size_t i=0;i<obj_size;i++)
-	    constr(tmp+i,data[i]);
-	 if (data)
-	 {
-	    for (iterator i=begin();i!=end();i++)
-	       destr(i);
-	    delete[] (char *)(data);
-	 }
-#else
-	 memcpy(tmp, data, obj_size*sizeof(T));
-	 if (data)
-	    delete[] (char *)(data);
-#endif
-	 data = tmp;
-	 obj_capacity = new_capacity;
-      }
-
-      for (size_t i=obj_size;i<new_size;i++)
-	 constr(data+i,x);
-
-   } else {
-
-      for (size_t i=new_size;i<obj_size;i++)
-	 destr(data+i);
-
-   }
-   obj_size = new_size;
+///clone default implementation
+template <class T>
+inline ObjectRef Vector<T>::clone() {
+  Vector<T> *cpy = Vector<T>::alloc(this->size());
+  
+  for (int i = 0; i < this->size(); i++) {
+    (*cpy)[i] = (*this)[i];
+  }
+  return ObjectRef(cpy);
 }
 
-template<class T>
-void Vector<T>::insert(iterator after, const T &x)
-{
-   size_t pos = after-begin();
-   if (obj_size+1 > obj_capacity)
-   {
-      size_t new_capacity = realloc_size(obj_size+1);
-      //Allocate new memory
-      T* tmp = (T*)new char [new_capacity*sizeof(T)];
 
-#if 1
-      //copy the elements before the inserted object
-      for (size_t i=0;i<pos;i++)
-	 constr(tmp+i,data[i]);
-      //copy inserted object
-      constr(tmp+pos,x);
-      //copy elements after insertion
-      for (size_t i=pos+1;i<obj_size+1;i++)
-	 constr(tmp+i,data[i-1]);
-      //Free old memory
-      if (data)
-      {
-	 for (iterator i=begin();i!=end();i++)
-	    destr(i);
-	 delete[] (char *)(data);
-      }
-      data = tmp;
-#else
-      memcpy(tmp, data, pos*sizeof(T));
-      constr(tmp+pos,x);
-      memcpy(tmp+pos+1, data+pos, (end()-after)*sizeof(T));
-      if (data)
-	 delete[] (char *)(data);
-      data = tmp;
-#endif
-      obj_capacity = new_capacity;
-   } else {
-#if 1
-      for (iterator i=after+1;i<end()+1;i++)
-      {
-	 constr(i,*(i-1));
-	 destr(i-1);
-      }
-      constr(after,x);
-#else
-      memmove(after+1, after, (end()-after)*sizeof(T));
-      constr(after,x);
-#endif
-   }
-   obj_size++;
+///clone implementation with Vector<ObjectRef>
+template <>
+inline ObjectRef Vector<ObjectRef>::clone() {
+  
+  Vector<ObjectRef> *cpy = new Vector<ObjectRef>(this->size());
+  
+  for (int i = 0; i < this->size(); i++) {
+    //cloning every Object in the vector
+    (*cpy)[i] = (*this)[i]->clone();
+  }
+
+  return ObjectRef(cpy);
 }
 
-template<class T>
-void Vector<T>::erase(iterator it)
-{
-#if 1
-   for (iterator i=it;i<end()-1;i++)
-   {
-      destr(i);
-      constr(i,*(i+1));
-   }
-#else
-   memmove(it+1, it, (end()-it-1)*sizeof(T));
-#endif
-   destr(end()-1);
-   obj_size--;
-}
 
 /*template <class T>
 inline ostream &operator << (ostream &out, const Vector<T> &v)
@@ -333,10 +257,34 @@ inline void _vector_printOn(const Vector<T> &v, ostream &out)
 }
 
 template <>
-inline void _vector_printOn(const Vector<string> &v, ostream &out);
+inline void _vector_printOn(const Vector<string> &v, ostream &out)
+{
+   out << "<Vector<string>";
+   for (unsigned int n=0; n < v.size(); n++)
+   {
+      out << " ";
+      const string &str = v[n];
+      for (unsigned int i=0;i<str.size();i++)
+      {
+	 if (str[i] == '>')
+	 {
+	    out.put('\\');
+	    out.put('>');
+	 } else if (str[i] == ' ')
+	 {
+	    out.put('\\');
+	    out.put(' ');
+	 } else if (str[i] == '\\')
+	 {
+	    out.put('\\');
+	    out.put('\\');
+	 } else
+	    out.put(str[i]);
+      }
+   }
+   out << "> ";
+}
 
-/*The following code doesn't compile on MSVC++*/
-#ifndef BROKEN_TEMPLATES
 template <class T>
 inline void _vector_printOn(const Vector<T*> &v, ostream &out)
 {
@@ -347,7 +295,6 @@ inline void _vector_printOn(const Vector<T*> &v, ostream &out)
    }
    out << " > ";
 }
-#endif
 
 template <class T>
 void Vector<T>::printOn(ostream &out) const
@@ -400,11 +347,58 @@ inline void _vector_readFrom(Vector<T> &v, istream &in)
       throw new GeneralException("Error reading Vector: '>' expected", __FILE__, __LINE__);
 }
 
-template <>
-inline void _vector_readFrom(Vector<string> &v, istream &in);
 
-/*The following code doesn't compile on MSVC++*/
-#ifndef BROKEN_TEMPLATES
+template <>
+inline void _vector_readFrom(Vector<string> &v, istream &in)
+{
+   bool done=false;
+   while (1)
+   {      
+      string tmp;
+      int i=0;
+      while(1)
+      {
+	 char ch;
+	 in.get(ch);
+	 if (in.eof() || in.fail())
+	    throw new GeneralException("Error reading String: '>' or '}' expected", __FILE__, __LINE__);
+	 if (ch == '\\')
+	 {
+	    in.get(ch);
+	    tmp += ch;
+	 }
+	 else if (ch == ' ')
+	 {
+	    if (i)
+	    {
+	       break;
+	    }
+	    else
+	       continue;
+	 }
+	 else if (ch == '>')
+	 {
+	    done=true;
+	    break;
+	 }
+	 else if (ch == '}')
+	 {
+	    break;
+	 }
+	 else
+	 {
+	    tmp += ch;
+	 }
+	 i++;
+      }
+
+      if (tmp != "")
+	 v.push_back(tmp);
+      if (done)
+	 break;
+   }
+}
+
 template <class T>
 inline void _vector_readFrom(Vector<T*> &v, istream &in)
 {
@@ -432,7 +426,6 @@ inline void _vector_readFrom(Vector<T*> &v, istream &in)
    }
 }
 
-#endif
 
 template <class T>
 inline void Vector<T>::readFrom(istream &in)
@@ -440,24 +433,29 @@ inline void Vector<T>::readFrom(istream &in)
    _vector_readFrom(*this, in);
 }
 
-/*The following code requires template partial specialization*/
-#ifndef BROKEN_TEMPLATES
-
 //FIXME: Serialize problems with (Object *)
 template<class T, int I>
-struct VecBinary {
+struct VecMethod {
    static inline void serialize(const Vector<T> &v, ostream &out)
    {
-      throw new GeneralException("VecBinary default serialize should never be called", __FILE__, __LINE__);
+     throw new GeneralException("VecMethod default serialize should never be called", __FILE__, __LINE__);
    }
    static inline void unserialize(Vector<T> &v, istream &in)
    {
-      throw new GeneralException("VecBinary default unserialize should never be called", __FILE__, __LINE__);
+     throw new GeneralException("VecMethod default unserialize should never be called", __FILE__, __LINE__);
+   }  
+   static inline ObjectRef getIndex(Vector<T> &v, int pos) 
+   {
+     throw new GeneralException("VecMethod getIndex should never be called", __FILE__, __LINE__);   				
+   }   
+   static inline void setIndex(Vector<T> &v, int pos, ObjectRef val) 
+   {
+     throw new GeneralException("VecMethod setIndex should never be called", __FILE__, __LINE__);   				
    }
 };
 
 template<class T>
-struct VecBinary<T,TTraits::Object> {
+struct VecMethod<T,TTraits::Object> {
    static inline void serialize(const Vector<T> &v, ostream &out)
    {
       out << "{" << v.className() << endl;
@@ -485,10 +483,28 @@ struct VecBinary<T,TTraits::Object> {
       char ch;
       in >> ch;
    }
+  
+
+   static inline ObjectRef getIndex(Vector<T> &v, int pos) 
+   {
+     if (pos < 0 || pos >= v.size()) {
+       throw new GeneralException("Vector getIndex : index out of bound",__FILE__,__LINE__);
+     }
+     return ObjectRef(v[pos].clone());
+   }   
+
+   static inline void setIndex(Vector<T> &v, int pos, ObjectRef val) 
+   {
+     if (pos < 0 || pos >= v.size()) {
+       throw new GeneralException("Vector getIndex : index out of bound",__FILE__,__LINE__);
+     }
+     RCPtr<T> obj = val;
+     v[pos] = *obj;
+   }
 };
 
 template<class T>
-struct VecBinary<T,TTraits::ObjectPointer> {
+struct VecMethod<T,TTraits::ObjectPointer> {
    static inline void serialize(const Vector<T> &v, ostream &out)
    {
       out << "{" << v.className() << endl;
@@ -513,18 +529,34 @@ struct VecBinary<T,TTraits::ObjectPointer> {
       char ch;
       in >> ch;
    }
+
+   static inline ObjectRef getIndex(Vector<T> &v, int pos) 
+   {
+     if (pos < 0 || pos >= v.size()) {
+       throw new GeneralException("Vector getIndex : index out of bound",__FILE__,__LINE__);
+     }
+     return v[pos];
+   }   
+
+   static inline void setIndex(Vector<T> &v, int pos, ObjectRef val) 
+   {
+     if (pos < 0 || pos >= v.size()) {
+       throw new GeneralException("Vector getIndex : index out of bound",__FILE__,__LINE__);
+     }
+     v[pos] = val;
+   }
 };
 
 
 template<class T>
-struct VecBinary<T,TTraits::Basic> {
+struct VecMethod<T,TTraits::Basic> {
    static inline void serialize(const Vector<T> &v, ostream &out)
    {
       out << "{" << v.className() << endl;
       out << "|";
       int tmp=v.size();
       BinIO::write(out, &tmp, 1);
-      BinIO::write(out, &(const_cast<Vector<T> &>(v))[0], v.size());
+      BinIO::write(out, &v[0], v.size());
       out << "}";
    }
    static inline void unserialize(Vector<T> &v, istream &in)
@@ -532,14 +564,31 @@ struct VecBinary<T,TTraits::Basic> {
       int tmp;
       BinIO::read(in, &tmp, 1);
       v.resize(tmp);
-      BinIO::read(in, &(const_cast<Vector<T> &>(v))[0], v.size());
+      BinIO::read(in, &v[0], v.size());
       char ch;
       in >> ch;
    }
+   
+   static inline ObjectRef getIndex(Vector<T> &v, int pos) 
+   {
+     if (pos < 0 || pos >= v.size()) {
+       throw new GeneralException("Vector getIndex : index out of bound",__FILE__,__LINE__);
+     }     
+     return ObjectRef( NetCType<T>::alloc(v[pos]));
+   }   
+   
+   static inline void setIndex(Vector<T> &v, int pos, ObjectRef val) 
+   {
+     if (pos < 0 || pos >= v.size()) {
+       throw new GeneralException("Vector getIndex : index out of bound",__FILE__,__LINE__);
+     }  
+     RCPtr<NetCType<T> > obj = val;     
+     v[pos] = *obj;   
+   }
 };
 
 template<class T>
-struct VecBinary<T,TTraits::Unknown> {
+struct VecMethod<T,TTraits::Unknown> {
    static inline void serialize(const Vector<T> &v, ostream &out)
    {
       throw new GeneralException(string("Sorry, can't serialize this kind of object (") + typeid(T).name()
@@ -550,37 +599,43 @@ struct VecBinary<T,TTraits::Unknown> {
       throw new GeneralException(string("Sorry, can't unserialize this kind of object (") + typeid(T).name()
 				 + ")", __FILE__, __LINE__);
    }
-};
 
-#else /* #ifndef BROKEN_TEMPLATES */
-
-/* This is for broken compilers */
-template<class T, int I>
-struct VecBinary {
-   static inline void serialize(const Vector<T> &v, ostream &out)
+   static inline ObjectRef getIndex(Vector<T> &v, int pos) 
    {
-      throw new GeneralException("Binary IO not supported because compiler doesn't support template partial specialization", __FILE__, __LINE__);
+     throw new GeneralException(string("Sorry, can't getIndex for this type of vector (") + typeid(T).name()
+				 + ")", __FILE__, __LINE__);
    }
-   static inline void unserialize(Vector<T> &v, istream &in)
+   
+   static inline void setIndex(Vector<T> &v, int pos, ObjectRef val) 
    {
-      throw new GeneralException("Binary IO not supported because compiler doesn't support template partial specialization", __FILE__, __LINE__);
+     throw new GeneralException(string("Sorry, can't getIndex for this type of vector (") + typeid(T).name()
+				+ ")", __FILE__, __LINE__);
    }
 };
 
-#endif
-
 template <class T>
 inline void Vector<T>::serialize(ostream &out) const
 {
-   VecBinary<T, TypeTraits<T>::kind>::serialize(*this, out);
+   VecMethod<T, TypeTraits<T>::kind>::serialize(*this, out);
 }
 
 template <class T>
 inline void Vector<T>::unserialize(istream &in)
 {
-   VecBinary<T, TypeTraits<T>::kind>::unserialize(*this, in);
+   VecMethod<T, TypeTraits<T>::kind>::unserialize(*this, in);
 }
 
+template <class T>
+inline ObjectRef Vector<T>::getIndex(int pos)
+{
+  return VecMethod<T, TypeTraits<T>::kind>::getIndex(*this,pos);
+}
+
+template <class T>
+inline void Vector<T>::setIndex(int pos, ObjectRef val)
+{
+  VecMethod<T, TypeTraits<T>::kind>::setIndex(*this,pos,val);
+}
 
 
 template <class T>
@@ -819,15 +874,6 @@ inline Vector<T> operator/ (const Vector<T> &v1, T scal)
 }
 
 
-/*T operator* (const Vector<T> &v2) 
-{
-   if (size() != v2.size())
-      cerr << "Vector size mismatch\n";
-   T sum=0;
-   for (int i=0;i<size();i++)
-      sum += operator[](i)*v2[i];
-   return sum;
-   }*/
 
 
 
