@@ -18,6 +18,7 @@
 #include <fstream>
 #include <fcntl.h>
 #include "stream_wrap.h"
+#include "object_param.h"
 
 //@implements UIClasses
 
@@ -148,7 +149,7 @@ void UIDocument::load()
 	 docFile >> ch;
 	 if (docFile.fail())
 	 {
-	    error("Error: this doesn't look like an Overflow document");
+	    error("Error: this doesn't look like an FlowDesigner document");
 	    addNetwork("MAIN", UINetwork::subnet);
 	    resetModified();
 	    return;
@@ -156,7 +157,7 @@ void UIDocument::load()
       }
    } else if (ch!='<')
    {
-      error("Error: this doesn't look like an Overflow document");
+      error("Error: this doesn't look like an FlowDesigner document");
       addNetwork("MAIN", UINetwork::subnet);
       resetModified();
       return;
@@ -165,7 +166,7 @@ void UIDocument::load()
    docFile >> xmlStr;
    if (xmlStr != "?xml")
    {
-      error("Error: this doesn't look like an Overflow document");
+      error("Error: this doesn't look like an FlowDesigner document");
       addNetwork("MAIN", UINetwork::subnet);
       resetModified();
       return;      
@@ -226,13 +227,43 @@ void UIDocument::loadXML(xmlNodePtr root)
       free (comments);
    }
 
+   //loading networks
    xmlNodePtr net = root->children;
    //cerr << "parsing...\n";
    while (net != NULL)
    {
-      //cerr << "start net\n";
+      //Standard network found
       if (string((char*)net->name) == "Network")
+      {
 	addNetwork (net);
+      }
+      //File included (prototype)
+      if (string((char*)net->name) == "IncludeNetwork") 
+      {
+	
+	cerr<<"Warning, included network is still a prototype, use at your own risk"<<endl;
+	xmlChar *fname = xmlGetProp(net,(xmlChar *)"file");
+	
+	if (fname) 
+	{
+	  cerr<<"Including : "<<(char*) fname<<endl;
+	  try 
+	  {
+	    //let's import the network
+	    importNetwork(string((char*) fname));
+	    
+	  }
+	  catch(BaseException *e) 
+	  {
+	    e->print(cerr);
+	    delete e;
+	  }
+	  free(fname);
+	}
+      }
+
+
+
       net = net->next;
    }
 
@@ -263,14 +294,14 @@ void UIDocument::loadXML(xmlNodePtr root)
 	 free(str_name); free(str_type); free(str_value);
          
          for (unsigned int i=0;i<textParams.size();i++)
-     {
-        if (textParams[i]->name == name)
-        {
-           textParams[i]->type = type;
-           textParams[i]->value = value;
-           //insertLoadedParam(param, type, value);
-        }
-     }
+	   {
+	     if (textParams[i]->name == name)
+	       {
+		 textParams[i]->type = type;
+		 textParams[i]->value = value;
+		 //insertLoadedParam(param, type, value);		 
+	       }
+	   }
          //cerr << "<param: " << name << ", " << type << ":" << value << ">\n";
       }
       par = par->next;
@@ -332,21 +363,34 @@ UINetwork *UIDocument::addNetwork(string name, UINetwork::Type type)
 
 UINetwork *UIDocument::addNetwork(xmlNodePtr xmlNet)
 {
-   //cerr << "creating...\n";
-   UINetwork *newNet = newNetwork(xmlNet);
-   //cerr << "created\n";
-   //cerr << "newNet = " << newNet << endl;
-   //cerr << "network created in UIDocument::addNetwork\n";
-   for (unsigned int i=0;i<networks.size();i++)
-   {
+
+  //cerr << "creating...\n";
+  UINetwork *newNet = newNetwork(xmlNet);
+  
+  //look for existing network before adding
+  UINetwork *tmp_net = getNetworkNamed(newNet->getName());
+  
+  if (tmp_net != NULL) {
+    string netName = newNet->getName();
+    delete newNet;
+    throw new GeneralException(string("Network (") + netName + string(") already exists"),__FILE__,__LINE__);
+  }
+ 
+ 
+  //cerr << "created\n";
+  //cerr << "newNet = " << newNet << endl;
+  //cerr << "network created in UIDocument::addNetwork\n";
+  
+  for (unsigned int i=0;i<networks.size();i++)
+    {
       networks[i]->newNetNotify("Subnet",newNet->getName());
       newNet->newNetNotify("Subnet",networks[i]->getName());
-   }
-   //cerr << "newNet = " << newNet << endl;
-   networks.insert(networks.end(), newNet);
-
-   modified = true;
-   return newNet;
+    }
+  //cerr << "newNet = " << newNet << endl;
+  networks.insert(networks.end(), newNet);
+  
+  modified = true;
+  return newNet;
 }
 
 //This function looks useless. Is it?
@@ -517,10 +561,14 @@ Network *UIDocument::buildExternal(const string &type, const string &_name, cons
    doc.load();
    
    UINetwork *net = doc.getNetworkNamed("MAIN");
-   if (net)
-      return net->build(_name, params);
+   if (net) 
+   {
+     return net->build(_name, params);     
+   }
    else
-      throw new GeneralException("No MAIN network defined", __FILE__, __LINE__);
+   {
+     throw new GeneralException("No MAIN network defined", __FILE__, __LINE__);
+   }
 }
 
 
@@ -531,7 +579,23 @@ Network *UIDocument::build(const string &_name, const ParameterSet &params)
       UINetwork *uinet = getNetworkNamed("MAIN");
       if (!uinet)
 	 throw new GeneralException("No MAIN network defined", __FILE__, __LINE__);
-      net = uinet->build(_name, params);
+
+      //copy params
+      ParameterSet myParams = params;
+
+      //adding document params            
+      for (int i = 0; i < textParams.size(); i++) 
+      {		
+	if (!myParams.exist(textParams[i]->name)) {
+	  //create object
+	  ObjectRef param_value = ObjectParam::stringParam(textParams[i]->type,textParams[i]->value,myParams);
+
+	  //adding default param value if not specified into arguments
+	  myParams.add(textParams[i]->name,param_value);	
+	}
+      }
+
+      net = uinet->build(_name, myParams);
       net->verifyConnect();
       return net;
    } catch (BaseException *e)
@@ -717,3 +781,170 @@ void UIDocument::updateAllSubnetTerminals(const string _nettype, const string _t
          networks[i]->updateAllSubnetTerminals(_nettype, _terminalname, _terminaltype, _remove);
    }
 }
+
+void UIDocument::exportNetwork(const std::string &networkName, const std::string &fileName) {
+
+  UINetwork *net = getNetworkNamed(networkName);
+
+  if (net) {
+
+    int save_fd = open(fileName.c_str(), O_CREAT|O_WRONLY|O_TRUNC, 00755);
+    if (save_fd == -1) {
+	error("UIDocument::exportNetwork : Error while saving file: cannot open");
+	return; 
+    }
+    fd_ostream outFile(save_fd);
+    if (outFile.fail()) {
+      error("UIDocument::exportNetwork : Error while saving file");
+      return;
+    }
+    
+    xmlDocPtr doc;
+    doc = xmlNewDoc((xmlChar *)"1.0");
+    doc->children = xmlNewDocNode(doc, NULL, (xmlChar *)"Document", NULL);
+    
+
+    //Export network  
+    net->saveXML(doc->children);
+
+    char *mem = NULL;
+    int size = 0;
+
+    //Dump to memory
+    xmlDocDumpFormatMemory(doc,(xmlChar **)&mem,&size, 1);
+    xmlFreeDoc(doc);
+
+    //Write to file
+    outFile.write(mem, size);
+    if (outFile.fail()) {
+	free(mem);
+	error("UIDocument::exportNetwork : Error while saving file");
+	return;
+    }
+    
+    //Free memory
+    free(mem);
+  }
+  else {
+    //TODO throw an exception ?
+    throw new GeneralException(string("Network does not exist :") + networkName,__FILE__,__LINE__);
+  }
+}
+
+   
+   
+void UIDocument::importNetwork(const std::string &fileName) {
+
+  //TODO Merge stuff with load to avoid duplication of the code.
+  //The difference is that we do not reset document data before loading
+  //and we do not create a "MAIN" network.
+ 
+  string docStr;
+
+  ifstream inputFile(fileName.c_str());
+
+  if (!inputFile.fail()) {
+
+    char ch;
+    inputFile >> ch;
+    if (ch=='#') 
+    {
+        //let's read the leading characters (script like format)
+	while (ch != '<')
+	{
+	  inputFile >> ch;
+	  if (inputFile.fail())
+	  {
+	    error("Error: this doesn't look like an FlowDesigner document");
+	    resetModified();
+	    return;
+	  }
+        }
+   } else if (ch!='<')
+   {
+      error("Error: this doesn't look like an FlowDesigner document");
+      resetModified();
+      return;
+   }
+   string xmlStr;
+   inputFile >> xmlStr;
+   if (xmlStr != "?xml")
+   {
+      error("Error: this doesn't look like an FlowDesigner document");
+      resetModified();
+      return;      
+   }
+
+   //put back xml starting string
+   docStr = "<?xml";
+
+    //read all data from file
+    while(1) {
+      char buff[1025];
+      inputFile.read(buff, 1024);
+      buff[1024]=0;
+      if (inputFile.fail()) {
+	docStr.append(buff, inputFile.gcount());
+	break; 
+      }
+      docStr.append(buff, 1024);
+    }
+
+    try {
+      //loading document
+      xmlDocPtr doc = xmlParseMemory (const_cast<char *> (docStr.c_str()), docStr.size());
+
+      if (!doc || !doc->children || !doc->children->name) {
+	throw new GeneralException(string("Corrupted XML in file ") + fileName,__FILE__,__LINE__);
+      }
+            
+      xmlNodePtr net = doc->children->children;
+
+      if (net) {
+ 
+	//loading all networks
+	while (net != NULL) {	
+
+	  //Standard network
+	  if (string((char*)net->name) == "Network") {
+	    addNetwork (net);
+	  }
+
+	  //File included (prototype)
+	  if (string((char*)net->name) == "IncludeNetwork") {
+	    
+	    cerr<<"Warning, included network is still a prototype, use at your own risk"<<endl;
+	    xmlChar *fname = xmlGetProp(net,(xmlChar *)"file");
+	    
+	    if (fname) {
+	      cerr<<"(Recursive) Including : "<<(char*) fname<<endl;
+	      try {
+		//let's import the network
+		importNetwork(string((char*) fname));
+		
+	      }
+	      catch(BaseException *e) {
+		e->print(cerr);
+		delete e;
+	      }
+	      free(fname);
+	    }//Valid filename		
+	  }//IncludeNetwork	     
+	  net = net->next;
+	}//while net
+      }
+
+      //free XML data
+      xmlFreeDoc(doc);
+      
+      //the network is modified
+      setModified();
+    }
+    catch (BaseException *e) {
+       throw e->add(new GeneralException(string("Unable to import from file ") + fileName,__FILE__,__LINE__));
+    }
+  }
+  else {
+    throw new GeneralException(string("File does not exist : ") + fileName,__FILE__,__LINE__);
+  }
+}
