@@ -1,14 +1,15 @@
 // Copyright (C) 2001 Jean-Marc Valin
 
+#include <typeinfo>
+#include <pthread.h>
+#include <sstream>
+
 #include "vflow.h"
 #include "GUIDocument.h"
 #include "GUINetwork.h"
-#include <typeinfo>
 #include "ParameterSet.h"
 #include "Network.h"
-#include <pthread.h>
 #include "rc_ptrs.h"
-#include <sstream>
 #include "object_param.h"
 #include "UserException.h"
 
@@ -139,8 +140,25 @@ Dominic Letourneau (13/09/2003)
 **********************************************************************************************************/
 void GUIDocument::add_notebook_network(GUINetwork *net, GtkWidget *child) {
 
+
+  string tabName = net->getName();
+
+  switch(net->getType()) {
+  case UINetwork::subnet:
+    tabName = tabName + " (subnet)";
+    break;
+  case UINetwork::iterator:
+    tabName = tabName + " (iterator)";
+    break;
+  case UINetwork::threaded:
+    tabName = tabName + " (threaded iterator)";
+    break;
+  default:
+    tabName = tabName + " (unknown)";
+  }
+
   //creating label for the notebook page
-  GtkWidget *label1 = gtk_label_new ((gchar *)net->getName().c_str());
+  GtkWidget *label1 = gtk_label_new ((gchar *)tabName.c_str());
   gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_LEFT);
   gtk_widget_show (label1);
   
@@ -377,8 +395,25 @@ void GUIDocument::renameCurrentNet() {
       //update network name
       net->rename(newName);
 
+      //updating text    
+      string tabName=newName;
+      
+      switch (net->getType()) {
+      case UINetwork::subnet:
+	tabName = tabName + " (subnet)";
+	break;
+      case UINetwork::iterator:
+	tabName = tabName + " (iterator)";
+	break;
+      case UINetwork::threaded:
+	tabName = tabName + " (threaded iterator)";
+	break;
+      default:
+	tabName = tabName + " (unknown)";  
+      }
+
       //update notebook label
-      gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(document_notebook), net->getView(), newName.c_str());
+      gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(document_notebook), net->getView(), tabName.c_str());
 
       //SHOULD RENAME ALL SUBNET NODES ?
       
