@@ -3,6 +3,7 @@
 #include "GUINetwork.h"
 #include "GUIDocument.h"
 #include "GUINode.h"
+#include "GUINote.h"
 #include "GUITerminal.h"
 #include <libxml/tree.h>
 #include "GUILink.h"
@@ -13,6 +14,7 @@
 #include "misc.h"
 #include "GUINodeTooltip.h"
 #include <sstream>
+#include "GUINote.h"
 
 /*static gboolean net_canvas_event   (GtkWidget       *widget,
                                      GdkEventButton  *event,
@@ -143,37 +145,8 @@ void GUINetwork::create()
    gtk_container_add (GTK_CONTAINER (scrolledwindow1), canvas1);
    gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas1), -400, -400, 400, 400);
 
-   string tabName=name;
-   switch (type)
-   {
-      case subnet:
-	 tabName = tabName + " (subnet)";
-	 break;
-      case iterator:
-	 tabName = tabName + " (iterator)";
-	 break;
-      case threaded:
-	 tabName = tabName + " (threaded iterator)";
-	 break;
-      default:
-	 tabName = tabName + " (unknown)";
-
-	 
-   }
-
-
-   //add network to document notebook
-
-   //GtkWidget *document_notebook = dynamic_cast<GUIDocument *>(doc)->getNotebook();
-   //GtkWidget *label1 = gtk_label_new ((gchar*)tabName.c_str());
-   //gtk_widget_ref (label1);
-   //gtk_object_set_data_full (GTK_OBJECT (scrolledwindow1), "label1", label1,
-   //                          (GtkDestroyNotify) gtk_widget_unref);
-   //gtk_widget_show (label1);
-   //gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label1);
-   //gtk_notebook_append_page(GTK_NOTEBOOK(document_notebook), scrolledwindow1, label1);
-   //gtk_notebook_set_current_page (GTK_NOTEBOOK(document_notebook), -1);
    
+   //add this network to the document
    dynamic_cast<GUIDocument*>(doc)->add_notebook_network(this,scrolledwindow1);
 
 
@@ -600,22 +573,7 @@ void GUINetwork::rename(string newName) {
   try {
     UINetwork::rename(newName);
 
-    //updating text    
-    string tabName=newName;
-    
-    switch (type) {
-    case subnet:
-      tabName = tabName + " (subnet)";
-      break;
-    case iterator:
-      tabName = tabName + " (iterator)";
-      break;
-    case threaded:
-      tabName = tabName + " (threaded iterator)";
-      break;
-    default:
-    tabName = tabName + " (unknown)";  
-    }
+    setModified();
   }
   catch (BaseException *e) {
     stringstream str;
@@ -719,3 +677,8 @@ void GUINetwork::applyNetworkProperties() {
     setModified();
   }
 }
+
+
+UINote* GUINetwork::newNote(const std::string &text, double x, double y, bool visible) {
+  return new GUINote(text,x,y,visible,this);
+}
