@@ -1,12 +1,13 @@
 // Copyright (C) 2001 Jean-Marc Valin & Dominic Letourneau
 
+#include <list>
+#include <sstream>
+#include <libxml/parser.h>
+
 #include "vflow.h"
 #include "iextensions.h"
-#include <list>
-#include <sstream>
 #include "vflow_pref.h"
 #include "flow_version.h"
-#include <libxml/parser.h>
 #include "misc_gui.h"
 #include "GUIDocument.h"
 #include "GUINetwork.h"
@@ -578,6 +579,10 @@ void saveas_doc_event(GtkWidget *widget, vflowGUI *vflow) {
    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->cancel_button),
                       "clicked", (GtkSignalFunc)file_saveas_destroy, 
                       ssel);
+
+   //set filename
+   gtk_file_selection_set_filename (GTK_FILE_SELECTION(ssel),(gchar*)doc->getName().c_str());
+
    
    gtk_widget_show(ssel);
    
@@ -768,6 +773,212 @@ static void remove_net_event  (GtkMenuItem     *menuitem,
  //cerr << "remove net\n";
 }
 
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+static void add_note_event(GtkMenuItem *menuitem, gpointer user_data) 
+{
+  cerr<<"Add a note (prototype) is not fully functionnal. Should display a GUI asking for comments"<<endl;
+  
+  GUIDocument *doc = vflowGUI::instance()->getCurrentDoc();
+
+  if (!doc) return;
+
+  UINetwork *net = doc->getCurrentNet();
+
+  if (!net) return;
+
+  net->addNote(net->newNote("Enter text here!",10.0,10.0,true));
+  
+  doc->setModified();
+
+}
+
+
+
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+void network_export_fsel_ok_sel(GtkWidget *w, UINetwork *net) {
+    
+  GtkWidget *ssel = GTK_WIDGET(gtk_object_get_user_data(GTK_OBJECT(w)));
+  gchar *fname = g_strdup(gtk_file_selection_get_filename (GTK_FILE_SELECTION(ssel)));
+  
+  if (fname && net) {
+    
+    GUIDocument *doc = dynamic_cast<GUIDocument*>(net->getDocument());
+    
+    if (doc) {
+      try {    
+	doc->exportNetwork(net->getName(),fname);
+      }
+      catch (BaseException *e) {
+	stringstream tmp_stream;
+	doc->less_print(tmp_stream.str());	
+	delete e;
+      } 
+
+
+      doc->less_print(string("Network (") + net->getName() + string(") exported to : ") + string(fname));
+    }
+  }
+  g_free (fname);
+  gtk_widget_destroy (GTK_WIDGET (ssel));
+  ssel = NULL;
+} 
+
+
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+gint network_export_fsel_destroy(GtkWidget *button, GtkWidget *sel) {
+
+  gtk_widget_destroy(sel);
+
+  return TRUE; 
+}
+
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+static void export_network_event(GtkMenuItem *menuitem, gpointer user_data) 
+{
+ 
+  try {
+  
+    GUIDocument *doc = vflowGUI::instance()->getCurrentDoc();
+    
+    if (!doc) return;
+    
+    UINetwork *net = doc->getCurrentNet();
+    
+    if (!net) return;
+    
+  
+    GtkWidget *ssel = gtk_file_selection_new("Export Network...");
+    
+
+
+
+    gtk_object_set_user_data(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->ok_button),ssel);
+    
+    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->ok_button),
+		       "clicked", (GtkSignalFunc) network_export_fsel_ok_sel, 
+		       net);
+    
+    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->cancel_button),
+		       "clicked", (GtkSignalFunc) network_export_fsel_destroy, 
+		       ssel);
+  
+
+    string defaultName = net->getName() + string(".n");
+
+    gtk_file_selection_set_filename (GTK_FILE_SELECTION(ssel), 
+				     defaultName.c_str());
+
+
+    gtk_widget_show(ssel);
+
+
+  }
+  catch (BaseException *e) {
+    stringstream tmp_stream;
+    e->print(tmp_stream);
+    
+    GUIDocument *doc = vflowGUI::instance()->getCurrentDoc();
+
+    if (doc) {
+      doc->less_print(tmp_stream.str());
+    }
+
+    delete e;
+  }
+
+}
+
+
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+void network_import_fsel_ok_sel(GtkWidget *w, GUIDocument *doc) {
+    
+  GtkWidget *ssel = GTK_WIDGET(gtk_object_get_user_data(GTK_OBJECT(w)));
+  gchar *fname = g_strdup(gtk_file_selection_get_filename (GTK_FILE_SELECTION(ssel)));
+  
+  if (fname && doc) {
+
+    try {
+
+      doc->importNetwork(string(fname));
+
+    }
+    catch (BaseException *e) {
+	stringstream tmp_stream;	
+	doc->less_print(tmp_stream.str());	
+	delete e;
+    }
+    
+    doc->less_print(string("Network file imported : ") + string(fname));
+  }
+  g_free (fname);
+  gtk_widget_destroy (GTK_WIDGET (ssel));
+  ssel = NULL;
+} 
+
+
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+gint network_import_fsel_destroy(GtkWidget *button, GtkWidget *sel) {
+
+  gtk_widget_destroy(sel);
+
+  return TRUE; 
+}
+
+
+/**********************************************************************************************************
+
+**********************************************************************************************************/
+static void import_network_event(GtkMenuItem *menuitem, gpointer user_data) 
+{
+  try {
+    GUIDocument *doc = vflowGUI::instance()->getCurrentDoc();
+    
+    if (!doc) return;
+ 
+  
+    GtkWidget *ssel = gtk_file_selection_new("Import Network...");
+    
+    gtk_object_set_user_data(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->ok_button),ssel);
+    
+    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->ok_button),
+		       "clicked", (GtkSignalFunc) network_import_fsel_ok_sel, 
+		       doc);
+    
+    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->cancel_button),
+		       "clicked", (GtkSignalFunc) network_import_fsel_destroy, 
+		       ssel);
+  
+    gtk_widget_show(ssel);
+
+  }
+  catch (BaseException *e) {
+    stringstream tmp_stream;
+    e->print(tmp_stream);
+
+    GUIDocument *doc = vflowGUI::instance()->getCurrentDoc();
+
+    if (doc) {
+      doc->less_print(tmp_stream.str());
+    }
+
+    delete e;
+  }
+}
+
+
+
 
 
 /**********************************************************************************************************
@@ -1107,7 +1318,29 @@ void vflowGUI::create_mdi ()
 	GNOME_APP_PIXMAP_NONE, NULL,
 	0, (GdkModifierType) 0, NULL
       },
-      
+      GNOMEUIINFO_SEPARATOR,
+      {
+	GNOME_APP_UI_ITEM, N_("Add Note"),
+	NULL,
+	(gpointer) add_note_event, NULL, NULL,
+	GNOME_APP_PIXMAP_NONE, NULL,
+	0, (GdkModifierType) 0, NULL
+      },
+      GNOMEUIINFO_SEPARATOR,
+      {
+	GNOME_APP_UI_ITEM, N_("Export Network"),
+	NULL,
+	(gpointer) export_network_event, NULL, NULL,
+	GNOME_APP_PIXMAP_NONE, NULL,
+	0, (GdkModifierType) 0, NULL
+      },
+      {
+	GNOME_APP_UI_ITEM, N_("Import Network"),
+	NULL,
+	(gpointer) import_network_event, NULL, NULL,
+	GNOME_APP_PIXMAP_NONE, NULL,
+	0, (GdkModifierType) 0, NULL
+      },      
       GNOMEUIINFO_END
     };
   
@@ -1331,6 +1564,11 @@ GLADE_HOOKUP_OBJECT (app1, edit1_menu_uiinfo[5].widget, "properties1");
   GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[4].widget, "rename_network1");
   GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[5].widget, "separator5");
   GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[6].widget, "remove_network1");
+  GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[7].widget, "separator6");
+  GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[8].widget, "add_note1");
+  GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[9].widget, "separator7");
+  GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[10].widget, "export_network1");
+  GLADE_HOOKUP_OBJECT (app1, networks_menu_uiinfo[11].widget, "import_network1");
   GLADE_HOOKUP_OBJECT (app1, menubar1_uiinfo[3].widget, "view1");
   GLADE_HOOKUP_OBJECT (app1, menubar1_uiinfo[4].widget, "help1");
   GLADE_HOOKUP_OBJECT (app1, help1_menu_uiinfo[0].widget, "user_guide1");
@@ -1354,7 +1592,7 @@ GLADE_HOOKUP_OBJECT (app1, edit1_menu_uiinfo[5].widget, "properties1");
   GLADE_HOOKUP_OBJECT (app1, appbar1, "appbar1");
 
 //return app1;
-gtk_widget_show (app1);
+//gtk_widget_show (app1);
 mdi=app1;
 
 set_run_mode(false);
@@ -1424,7 +1662,8 @@ int main (int argc, char *argv[])
       else {
 	vflow->create_empty_document();
       }
-      
+      //Fixes bad window placement code
+      gtk_widget_show (vflowGUI::instance()->get_mdi());
 
       //starting GTK loop
       gdk_threads_enter(); 
